@@ -215,7 +215,7 @@ class DicomReader:
 
                 images_data.append(image_data)
             except RuntimeError as e:
-                logging.info(f"      Simple ITK raised an error while loading the series named "
+                logging.info(f"      RuntimeError : {e}. Simple ITK raised an error while loading the series named "
                              f"{series_data.series_description}. This series is therefore ignored.")
 
         return images_data
